(publis)=

# Use in publications

Below, a list of publications making use of the xDEM package (that we are aware of!).

## Articles

### Pre-prints

- Hartl, L., Schmitt, P., Schuster, L., Helfricht, K., Abermann, J., & Maussion, F. (2024). **Recent observations and glacier modeling point towards near complete glacier loss in western Austria (Ötztal and Stubai mountain range) if 1.5 °C is not met**. <https://doi.org/10.5194/egusphere-2024-3146>
- Liu, Z., Filhol, S., & Treichler, D. (2024). **Retrieving snow depth distribution by downscaling ERA5 Reanalysis with ICESat-2 laser altimetry**. In arXiv [physics.geo-ph]. arXiv. <http://arxiv.org/abs/2410.17934>
- Mattea, E., Berthier, E., Dehecq, A., Bolch, T., Bhattacharya, A., Ghuffar, S., Barandun, M., & Hoelzle, M. (2024). **Five decades of Abramov glacier dynamics reconstructed with multi-sensor optical remote sensing**. <https://doi.org/10.5194/egusphere-2024-2169>
- Zhu, Y., Liu, S., Wei, J., Wu, K., Bolch, T., Xu, J., Guo, W., Jiang, Z., Xie, F., Yi, Y., Shangguan, D., Yao, X., & Zhang, Z. (2024). **Glacier-level and gridded mass change in the rivers’ sources in the eastern Tibetan Plateau (ETPR) from 1970s to 2000**. <https://doi.org/10.5194/essd-2024-255>
- Walden, J., Jacquemart, M., Higman, B., Hugonnet, R., Manconi, A., & Farinotti, D. (2024). **A regional analysis of paraglacial landslide activation in southern coastal Alaska**. <https://doi.org/10.5194/egusphere-2024-1086>

### 2024

- Dømgaard, M., Schomacker, A., Isaksson, E., Millan, R., Huiban, F., Dehecq, A., Fleischer, A., Moholdt, G., Andersen, J. K., & Bjørk, A. A. (2024). **Early aerial expedition photos reveal 85 years of glacier growth and stability in East Antarctica**. *Nature Communications*, 15(1), 4466. <https://doi.org/10.1038/s41467-024-48886-x>
- Piermattei, L., Zemp, M., Sommer, C., Brun, F., Braun, M. H., Andreassen, L. M., Belart, J. M. C., Berthier, E., Bhattacharya, A., Boehm Vock, L., Bolch, T., Dehecq, A., Dussaillant, I., Falaschi, D., Florentine, C., Floricioiu, D., Ginzler, C., Guillet, G., Hugonnet, R., … Yang, R. (2024). **Observing glacier elevation changes from spaceborne optical and radar sensors – an inter-comparison experiment using ASTER and TanDEM-X data**. *The Cryosphere*, 18(7), 3195–3230. <https://doi.org/10.5194/tc-18-3195-2024>

### 2023

- Bernat, M., Belart, J. M. C., Berthier, E., Jóhannesson, T., Hugonnet, R., Dehecq, A., Magnússon, E., & Gunnarsson, A. (2023). **Geodetic mass balance of Mýrdalsjökull ice cap, 1999--2021**. *Jökull*, 73(1), 35–53. <https://doi.org/10.33799/jokull2023.73.035>
- Khadka, N., Shrestha, N. ., Basnet, K., Manandhar, R., Sharma, S., & Shrestha, B. (2023). **Glacier Area, Mass and Associated Glacial Lake Change in Kawari basin, Western Nepal**. *Jalawaayu*, 3(1), 63–72. <https://doi.org/10.3126/jalawaayu.v3i1.52068>
- Brun, F., King, O., Réveillet, M., Amory, C., Planchot, A., Berthier, E., Dehecq, A., Bolch, T., Fourteau, K., Brondex, J., Dumont, M., Mayer, C., Leinss, S., Hugonnet, R., & Wagnon, P. (2023). **Everest South Col Glacier did not thin during the period 1984–2017**. *The Cryosphere*, 17(8), 3251–3268. <https://doi.org/10.5194/tc-17-3251-2023>
- Knuth, F., Shean, D., Bhushan, S., Schwat, E., Alexandrov, O., McNeil, C., Dehecq, A., Florentine, C., & O’Neel, S. (2023). **Historical Structure from Motion (HSfM): Automated processing of historical aerial photographs for long-term topographic change analysis**. *Remote Sensing of Environment*, 285, 113379. <https://doi.org/10.1016/j.rse.2022.113379>
- Schwat, E., Istanbulluoglu, E., Horner-Devine, A., Anderson, S., Knuth, F., & Shean, D. (2023). **Multi-decadal erosion rates from glacierized watersheds on Mount Baker, Washington, USA, reveal topographic, climatic, and lithologic controls on sediment yields**. *Geomorphology*, 438(108805), 108805. <https://doi.org/10.1016/j.geomorph.2023.108805>

### 2022

- Farnsworth, W. R., Ingólfsson, Ó., Mannerfelt, E. S., Kalliokoski, M. H., Guðmundsdóttir, E. R., Retelle, M., Allaart, L., Brynjólfsson, S., Furze, M. F. A., Hancock, H. J., Kjær, K. H., Pieńkowski, A. J., & Schomacker, A. (2022). **Vedde Ash constrains Younger Dryas glacier re-advance and rapid glacio-isostatic rebound on Svalbard**. *Quaternary Science Advances*, 5(100041), 100041. <https://doi.org/10.1016/j.qsa.2021.100041>
- Mannerfelt, E. S., Dehecq, A., Hugonnet, R., Hodel, E., Huss, M., Bauder, A., & Farinotti, D. (2022). **Halving of Swiss glacier volume since 1931 observed from terrestrial image photogrammetry**. *The Cryosphere*, 16(8), 3249–3268. <https://doi.org/10.5194/tc-16-3249-2022>
- Abad, L., Hölbling, D., Dabiri, Z., & Robson, B. A. (2022). **An open-source-based workflow for DEM generation from Sentinel-1 for landslide volume estimation**. *ISPRS - International Archives of the Photogrammetry Remote Sensing and Spatial Information Sciences*, XLVIII-4/W1-2022, 5–11. <https://doi.org/10.5194/isprs-archives-xlviii-4-w1-2022-5-2022>
- Hugonnet, R., Brun, F., Berthier, E., Dehecq, A., Mannerfelt, E. S., Eckert, N., & Farinotti, D. (2022). **Uncertainty Analysis of Digital Elevation Models by Spatial Inference From Stable Terrain**. *IEEE Journal of Selected Topics in Applied Earth Observations and Remote Sensing*, 15, 6456–6472. <https://doi.org/10.1109/JSTARS.2022.3188922>

## Theses

### PhD

- Hugonnet, R. (2022). **Global glacier mass change by spatiotemporal analysis of digital elevation models**, <https://theses.hal.science/tel-03813744>

### Master

- Vlieghe, P-L. (2023). **Revealing the Recent Height Changes of the Great Altesch Glacier Using TanDEM-X DEM Series**, <https://doi.org/10.3929/ethz-b-000637956>
- Saheed, A. (2023). **Investigation of changes in Briksdalsbreen, western Norway from 1966 - 2020**, <https://hdl.handle.net/11250/3057200>
- Liu, Z. (2022). **Snow Depth Retrieval and Downscaling using Satellite Laser Altimetry, Machine Learning, and Climate Reanalysis: A Case Study in Mainland Norway**, <https://hdl.handle.net/10852/103730>
- Bernat, M. (2022). **Geodetic mass balance of Mýrdalsjökull ice cap, 1999−2021: DEM processing and climate analysis**, <https://dumas.ccsd.cnrs.fr/dumas-03772002/>
